@@ -69,7 +69,7 @@ void AndroidFileListing::registerNativeMethods()
 {
 }
 
-void AndroidFileListing::executeInit(QHash<QUrl, QDateTime> allFiles)
+void AndroidFileListing::executeInit(const QHash<QUrl, QDateTime> &allFiles)
 {
     qCInfo(orgKdeElisaAndroid()) << "AndroidFileListing::executeInit";
     AbstractFileListing::executeInit(std::move(allFiles));
@@ -106,8 +106,13 @@ void AndroidFileListing::triggerRefreshOfContent()
 
     AbstractFileListing::triggerRefreshOfContent();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     QJniObject musicList = QJniObject::callStaticObjectMethod(
         "org/kde/elisa/ElisaActivity", "listAudioFiles", "(Landroid/content/Context;)Ljava/util/ArrayList;", QNativeInterface::QAndroidApplication::context());
+#else
+    QJniObject musicList = QJniObject::callStaticObjectMethod(
+        "org/kde/elisa/ElisaActivity", "listAudioFiles", "(Landroid/content/Context;)Ljava/util/ArrayList;", QNativeInterface::QAndroidApplication::context().object<jobject>());
+#endif
 
     auto nbTracks = musicList.callMethod<jint>("size");
 
